==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/state/grouping/NxmNxCtState.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.state.grouping;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxCtStateGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-ct-state {
 *     leaf ct-state {
 *         type uint32;
 *     }
 *     leaf mask {
 *         type uint32;
 *     }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-ct-state-grouping/nxm-nx-ct-state</i>
 *
 * <p>To create instances of this class use {@link NxmNxCtStateBuilder}.
 * @see NxmNxCtStateBuilder
 *
 */
public interface NxmNxCtState
    extends
    ChildOf<NxmNxCtStateGrouping>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.state.grouping.NxmNxCtState>
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:match",
        "2014-07-14", "nxm-nx-ct-state").intern();

    /**
     * @return <code>java.lang.Long</code> <code>ctState</code>, or <code>null</code> if not present
     */
    java.lang.Long getCtState();
    
    /**
     * @return <code>java.lang.Long</code> <code>mask</code>, or <code>null</code> if not present
     */
    java.lang.Long getMask();

}

==> openflowplugin-extension-nicira-0.7.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/state/grouping/NxmNxCtState.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.state.grouping;
import java.lang.Long;
import javax.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxCtStateGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-ct-state {
 *   leaf ct-state {
 *     type uint32;
 *   }
 *   leaf mask {
 *     type uint32;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-ct-state-grouping/nxm-nx-ct-state</i>
 *
 * <p>To create instances of this class use {@link NxmNxCtStateBuilder}.
 * @see NxmNxCtStateBuilder
 *
 */
public interface NxmNxCtState
    extends
    ChildOf<NxmNxCtStateGrouping>,
    Augmentable<NxmNxCtState>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-ct-state");

    /**
     * @return <code>java.lang.Long</code> <code>ctState</code>, or <code>null</code> if not present
     */
    @Nullable
    Long getCtState();
    
    /**
     * @return <code>java.lang.Long</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable
    Long getMask();

}
